@@ -13,9 +13,7 @@
  * GNU Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301, USA or on the web at http://www.gnu.org.
+ * along with this program; if not, see <https://www.gnu.org/licenses/>.
  */
 /**
  * SECTION: IpatchGigRegion
@@ -301,7 +299,7 @@ ipatch_gig_region_get_property(GObject *object, guint property_id,
 {
     IpatchGigRegion *region = IPATCH_GIG_REGION(object);
     IpatchRange range;
-    gboolean bool, retval;
+    gboolean flag, retval;
 
     switch(property_id)
     {
@@ -344,21 +342,21 @@ ipatch_gig_region_get_property(GObject *object, guint property_id,
         break;
 
     case PROP_SELF_NON_EXCLUSIVE:
-        bool = (ipatch_item_get_flags(IPATCH_ITEM(object))
+        flag = (ipatch_item_get_flags(IPATCH_ITEM(object))
                 & IPATCH_GIG_REGION_SELF_NON_EXCLUSIVE) > 0;
-        g_value_set_boolean(value, bool);
+        g_value_set_boolean(value, flag);
         break;
 
     case PROP_PHASE_MASTER:
-        bool = (ipatch_item_get_flags(IPATCH_ITEM(object))
+        flag = (ipatch_item_get_flags(IPATCH_ITEM(object))
                 & IPATCH_GIG_REGION_PHASE_MASTER) > 0;
-        g_value_set_boolean(value, bool);
+        g_value_set_boolean(value, flag);
         break;
 
     case PROP_MULTI_CHANNEL:
-        bool = (ipatch_item_get_flags(IPATCH_ITEM(object))
+        flag = (ipatch_item_get_flags(IPATCH_ITEM(object))
                 & IPATCH_GIG_REGION_MULTI_CHANNEL) > 0;
-        g_value_set_boolean(value, bool);
+        g_value_set_boolean(value, flag);
         break;
 
     default:
