@@ -13,9 +13,7 @@
  * GNU Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301, USA or on the web at http://www.gnu.org.
+ * along with this program; if not, see <https://www.gnu.org/licenses/>.
  */
 /*
  * IpatchSF2Gen_tables.c - SoundFont generator table structures
@@ -200,7 +198,7 @@ const IpatchSF2GenInfo ipatch_sf2_gen_info[] =
     /* Velocity */
     { {-1}, {127}, {-1}, IPATCH_UNIT_TYPE_INT, N_("Fixed Velocity"), NULL},
     /* InitAttenuation */
-    {   {0}, {1440}, {0}, IPATCH_UNIT_TYPE_CENTIBELS, N_("Attenuation"),
+    {   {0}, {3600}, {0}, IPATCH_UNIT_TYPE_SF2_ATTENUATION, N_("Attenuation"),
         N_("Volume attenuation")
     },
     /* Reserved2 */
